@@ -17,9 +17,16 @@ class GradientAlgorithm(GeneticAlgorithm):
     def run(self):
         self.generator.init(self.options['max_population_size'])
         t_s = time.time()
-        # create initial population and evaluate individuals
-        population = self.gen_initial_population()
-        self.evaluate(population.individuals)
-        self.problem.populations.append(population)
+
+        # create initial population
+        individuals = self.generator.generate()
+
+        # append to problem
+        for individual in individuals:
+            self.problem.individuals.append(individual)
+
+        # evaluate individuals
+        self.evaluate(individuals)
+
         t = time.time() - t_s
         self.problem.logger.info("Sweep: elapsed time: {} s".format(t))
